diff --git a/docs/.vuepress/navbar.ts b/docs/.vuepress/navbar.ts
index 20467d3..0a0a9d2 100644
--- a/docs/.vuepress/navbar.ts
+++ b/docs/.vuepress/navbar.ts
@@ -2,29 +2,6 @@ import { navbar } from "vuepress-theme-hope";
export default navbar([
"/",
- "/demo/",
- {
- text: "指南",
- icon: "lightbulb",
- prefix: "/guide/",
- children: [
- {
- text: "Bar",
- icon: "lightbulb",
- prefix: "bar/",
- children: ["baz", { text: "...", icon: "ellipsis", link: "" }],
- },
- {
- text: "Foo",
- icon: "lightbulb",
- prefix: "foo/",
- children: ["ray", { text: "...", icon: "ellipsis", link: "" }],
- },
- ],
- },
- {
- text: "V2 文档",
- icon: "book",
- link: "https://theme-hope.vuejs.press/zh/",
- },
+ "/deployment/",
+ "/usage/",
]);
diff --git a/docs/.vuepress/public/favicon.ico b/docs/.vuepress/public/favicon.ico
index b411f79..73e9e36 100644
Binary files a/docs/.vuepress/public/favicon.ico and b/docs/.vuepress/public/favicon.ico differ
diff --git a/docs/.vuepress/sidebar.ts b/docs/.vuepress/sidebar.ts
index a2b1556..d50fd55 100644
--- a/docs/.vuepress/sidebar.ts
+++ b/docs/.vuepress/sidebar.ts
@@ -4,22 +4,18 @@ export default sidebar({
"/": [
"",
{
- text: "案例",
+ text: "项目部署",
icon: "laptop-code",
- prefix: "demo/",
- link: "demo/",
+ prefix: "deployment/",
+ link: "deployment/",
children: "structure",
},
{
- text: "文档",
- icon: "book",
- prefix: "guide/",
+ text: "使用手册",
+ icon: "laptop-code",
+ prefix: "usage/",
+ link: "usage/",
children: "structure",
},
- {
- text: "幻灯片",
- icon: "person-chalkboard",
- link: "https://plugin-md-enhance.vuejs.press/zh/guide/content/revealjs/demo.html",
- },
],
});
diff --git a/docs/.vuepress/theme.js b/docs/.vuepress/theme.js
new file mode 100644
index 0000000..32e982e
--- /dev/null
+++ b/docs/.vuepress/theme.js
@@ -0,0 +1,187 @@
+import {hopeTheme} from "vuepress-theme-hope";
+import navbar from "./navbar.js";
+import sidebar from "./sidebar.js";
+
+export default hopeTheme({
+ hostname: "https://vuepress-theme-hope-docs-demo.netlify.app",
+
+ author: {
+ name: "SnowyKami",
+ url: "https://snowykami.me",
+ },
+
+ iconAssets: "fontawesome-with-brands",
+
+ logo: "https://cdn.liteyuki.icu/static/img/logo.png",
+
+ repo: "https://github.com/snowykami/LiteyukiBot",
+
+ docsDir: "src",
+
+ // 导航栏
+ navbar,
+
+ // 侧边栏
+ sidebar,
+
+ // 页脚
+ footer: "LiteyukiBot",
+ displayFooter: true,
+
+ // 加密配置
+ encrypt: {
+ config: {
+ "/demo/encrypt.html": ["1234"],
+ },
+ },
+
+ // 多语言配置
+ metaLocales: {
+ editLink: "在 GitHub 上编辑此页",
+ },
+
+ // 如果想要实时查看任何改变,启用它。注: 这对更新性能有很大负面影响
+ // hotReload: true,
+
+ // 在这里配置主题提供的插件
+ plugins: {
+ // 你应该自行生成自己的评论服务
+ comment: {
+ provider: "Giscus",
+ repo: "vuepress-theme-hope/giscus-discussions",
+ repoId: "R_kgDOG_Pt2A",
+ category: "Announcements",
+ categoryId: "DIC_kwDOG_Pt2M4COD69",
+ },
+
+ components: {
+ components: ["Badge", "VPCard"],
+ },
+
+ // 此处开启了很多功能用于演示,你应仅保留用到的功能。
+ mdEnhance: {
+ align: true,
+ attrs: true,
+ codetabs: true,
+ component: true,
+ demo: true,
+ figure: true,
+ imgLazyload: true,
+ imgSize: true,
+ include: true,
+ mark: true,
+ stylize: [
+ {
+ matcher: "Recommended",
+ replacer: ({tag}) => {
+ if (tag === "em")
+ return {
+ tag: "Badge",
+ attrs: {type: "tip"},
+ content: "Recommended",
+ };
+ },
+ },
+ ],
+ sub: true,
+ sup: true,
+ tabs: true,
+ vPre: true,
+
+ // 在启用之前安装 chart.js
+ // chart: true,
+
+ // insert component easily
+
+ // 在启用之前安装 echarts
+ // echarts: true,
+
+ // 在启用之前安装 flowchart.ts
+ // flowchart: true,
+
+ // gfm requires mathjax-full to provide tex support
+ // gfm: true,
+
+ // 在启用之前安装 katex
+ // katex: true,
+
+ // 在启用之前安装 mathjax-full
+ // mathjax: true,
+
+ // 在启用之前安装 mermaid
+ // mermaid: true,
+
+ // playground: {
+ // presets: ["ts", "vue"],
+ // },
+
+ // 在启用之前安装 reveal.js
+ // revealJs: {
+ // plugins: ["highlight", "math", "search", "notes", "zoom"],
+ // },
+
+ // 在启用之前安装 @vue/repl
+ // vuePlayground: true,
+
+ // install sandpack-vue3 before enabling it
+ // sandpack: true,
+ },
+
+ // 如果你需要 PWA。安装 @vuepress/plugin-pwa 并取消下方注释
+ // pwa: {
+ // favicon: "/favicon.ico",
+ // cacheHTML: true,
+ // cachePic: true,
+ // appendBase: true,
+ // apple: {
+ // icon: "/assets/icon/apple-icon-152.png",
+ // statusBarColor: "black",
+ // },
+ // msTile: {
+ // image: "/assets/icon/ms-icon-144.png",
+ // color: "#ffffff",
+ // },
+ // manifest: {
+ // icons: [
+ // {
+ // src: "/assets/icon/chrome-mask-512.png",
+ // sizes: "512x512",
+ // purpose: "maskable",
+ // type: "image/png",
+ // },
+ // {
+ // src: "/assets/icon/chrome-mask-192.png",
+ // sizes: "192x192",
+ // purpose: "maskable",
+ // type: "image/png",
+ // },
+ // {
+ // src: "/assets/icon/chrome-512.png",
+ // sizes: "512x512",
+ // type: "image/png",
+ // },
+ // {
+ // src: "/assets/icon/chrome-192.png",
+ // sizes: "192x192",
+ // type: "image/png",
+ // },
+ // ],
+ // shortcuts: [
+ // {
+ // name: "Demo",
+ // short_name: "Demo",
+ // url: "/demo/",
+ // icons: [
+ // {
+ // src: "/assets/icon/guide-maskable.png",
+ // sizes: "192x192",
+ // purpose: "maskable",
+ // type: "image/png",
+ // },
+ // ],
+ // },
+ // ],
+ // },
+ // },
+ },
+});
diff --git a/docs/README.md b/docs/README.md
index 16ef4fa..f68d08f 100644
--- a/docs/README.md
+++ b/docs/README.md
@@ -1,280 +1,42 @@
---
home: true
icon: home
-title: 项目主页
-heroImage: https://theme-hope-assets.vuejs.press/logo.svg
+title: 首页
+heroImage: https://cdn.liteyuki.icu/static/img/logo.png
bgImage: https://theme-hope-assets.vuejs.press/bg/6-light.svg
bgImageDark: https://theme-hope-assets.vuejs.press/bg/6-dark.svg
bgImageStyle:
background-attachment: fixed
-heroText: 项目名称
-tagline: 你可以在这里放置或是整个项目的描述。
+heroText: LiteyukiBot 6
+tagline: 基于Nonebot2的OneBot标准聊天机器人,不仅仅局限于OneBot
actions:
- text: 使用指南
icon: lightbulb
- link: ./demo/
+ link: ./usage/
type: primary
- text: 文档
link: ./guide/
+#1. 安装 `Git` 和 `Python3.10+` 环境
+#2. 克隆项目 `git clone https://github.com/snowykami/LiteyukiBot` (无法连接可以用`https://gitee.com/snowykami/LiteyukiBot`)
+#3. 切换目录`cd LiteyukiBot`
+#4. 安装依赖`pip install -r requirements.txt`(如果多个Python环境请指定后安装`pythonx -m pip install -r requirements.txt`)
+#5. 启动`python main.py`
+
highlights:
- - header: 易于安装
+ - header: 快速部署
image: /assets/image/box.svg
bgImage: https://theme-hope-assets.vuejs.press/bg/3-light.svg
bgImageDark: https://theme-hope-assets.vuejs.press/bg/3-dark.svg
highlights:
- - title: 运行 pnpm create vuepress-theme-hope hope-project
以创建一个新的主题项目。
- - title: 在已有项目根目录下运行 pnpm create vuepress-theme-hope add .
以在项目中添加主题。
-
- - header: 在 Markdown 中添加你想要的内容
- description: 我们扩展了标准的 CommonMark 规范,为你添加了成吨功能。
- image: /assets/image/markdown.svg
- bgImage: https://theme-hope-assets.vuejs.press/bg/2-light.svg
- bgImageDark: https://theme-hope-assets.vuejs.press/bg/2-dark.svg
- bgImageStyle:
- background-repeat: repeat
- background-size: initial
- features:
- - title: 链接检查
- icon: clipboard-check
- details: 检查 Markdown 链接
- link: https://theme-hope.vuejs.press/zh/guide/markdown/others.html#link-check
-
- - title: 提示容器支持
- icon: box-archive
- details: 用样式装饰 Markdown 内容
- link: https://theme-hope.vuejs.press/zh/guide/markdown/hint.html
-
- - title: GFM 警告
- icon: bell
- details: GFM 风格的警告容器
- link: https://theme-hope.vuejs.press/zh/guide/markdown/alert.html
-
- - title: 选项卡
- icon: table-columns
- details: 使用选项卡对相似内容进行分组
- link: https://theme-hope.vuejs.press/zh/guide/markdown/tabs.html
-
- - title: 代码组
- icon: code
- details: 使用选项卡对相似代码进行分组
- link: https://theme-hope.vuejs.press/zh/guide/markdown/code-tabs.html
-
- - title: 自定义对齐支持
- icon: align-center
- details: 让你在 Markdown 中对段落进行对齐
- link: https://theme-hope.vuejs.press/zh/guide/markdown/align.html
-
- - title: 自定义属性支持
- icon: code
- details: 让你为 Markdown 元素添加属性
- link: https://theme-hope.vuejs.press/zh/guide/markdown/attrs.html
-
- - title: 上下角标支持
- icon: superscript
- details: 你的 Markdown 现在将支持上下角标
- link: https://theme-hope.vuejs.press/zh/guide/markdown/sup-sub.html
-
- - title: 脚注
- icon: quote-left
- details: 你的 Markdown 现在将支持脚注
- link: https://theme-hope.vuejs.press/zh/guide/markdown/footnote.html
-
- - title: 标记支持
- icon: highlighter
- details: 让你在 Markdown 中对词句进行标记
- link: https://theme-hope.vuejs.press/zh/guide/markdown/mark.html
-
- - title: 任务列表
- icon: square-check
- details: 在 Markdown 中使用任务列表
- link: https://theme-hope.vuejs.press/zh/guide/markdown/tasklist.html
-
- - title: 图片语法
- icon: image
- details: 使用改进的语法指定图片大小与颜色模式
- link: https://theme-hope.vuejs.press/zh/guide/markdown/image.html
-
- - title: 组件支持
- icon: puzzle-piece
- details: 在 Markdown 中轻松插入组件
- link: https://theme-hope.vuejs.press/zh/guide/markdown/component.html
-
- - title: 图表支持
- icon: chart-simple
- details: 在 Markdown 中展示图表
- link: https://theme-hope.vuejs.press/zh/guide/markdown/chartjs.html
-
- - title: 流程图支持
- icon: route
- details: 可以在 Markdown 中直接写出流程图
- link: https://theme-hope.vuejs.press/zh/guide/markdown/flowchart.html
-
- - title: Mermaid 支持
- icon: chart-pie
- details: 可以在 Markdown 中添加 Mermaid 图例
- link: https://theme-hope.vuejs.press/zh/guide/markdown/mermaid.html
-
- - title: Tex 支持
- icon: square-root-variable
- details: Markdown 现在也可以支持 Tex 语法以显示公式
- link: https://theme-hope.vuejs.press/zh/guide/markdown/tex.html
-
- - title: 导入文件支持
- icon: fab fa-markdown
- details: 将你的文档分段,并在 Markdown 中导入
- link: https://theme-hope.vuejs.press/zh/guide/markdown/include.html
-
- - title: 交互演示支持
- icon: code
- details: 你可以在 Markdown 中添加交互演示
- link: https://theme-hope.vuejs.press/zh/guide/markdown/playground.html
-
- - title: Vue 交互演示支持
- icon: fab fa-vuejs
- details: 在交互演示中展示 Vue 组件
- link: https://theme-hope.vuejs.press/zh/guide/markdown/vue-playground.html
-
- - title: Sandpack 交互演示支持
- icon: code
- details: Sandpack 驱动的实时的编码环境
- link: https://theme-hope.vuejs.press/zh/guide/markdown/sandpack.html
-
- - title: 代码案例支持
- icon: laptop-code
- details: 你可以很方便的插入代码案例
- link: https://theme-hope.vuejs.press/zh/guide/markdown/demo.html
-
- - title: 幻灯片支持
- icon: person-chalkboard
- details: 通过 Reveal.js 在 Markdown 中插入幻灯片
- link: https://theme-hope.vuejs.press/zh/guide/markdown/revealjs.html
-
- - header: 布局
- description: 一个带有完整无障碍支持的响应式布局。
- image: /assets/image/layout.svg
- bgImage: https://theme-hope-assets.vuejs.press/bg/5-light.svg
- bgImageDark: https://theme-hope-assets.vuejs.press/bg/5-dark.svg
- highlights:
- - title: 布局增强
- icon: object-group
- details: 添加路径导航、页脚、改进的导航栏、改进的页面导航等。
- link: https://theme-hope.vuejs.press/zh/guide/layout/
-
- - title: 深色模式
- icon: circle-half-stroke
- details: 可以自由切换浅色模式与深色模式
- link: https://theme-hope.vuejs.press/zh/guide/interface/darkmode.html
-
- - title: 主题色切换
- icon: palette
- details: 支持自定义主题色并允许用户在预设的主题颜色之间切换
- link: https://theme-hope.vuejs.press/zh/guide/interface/theme-color.html
-
- - title: 幻灯片页面
- icon: person-chalkboard
- details: 添加幻灯片页面以显示你喜欢的内容
- link: https://theme-hope.vuejs.press/zh/guide/layout/slides
-
- - title: 更多
- icon: ellipsis
- details: RTL 布局,打印支持,全局按钮等
- link: https://theme-hope.vuejs.press/zh/guide/interface/others.html
-
- - header: 新功能
- image: /assets/image/features.svg
- bgImage: https://theme-hope-assets.vuejs.press/bg/1-light.svg
- bgImageDark: https://theme-hope-assets.vuejs.press/bg/1-dark.svg
- features:
- - title: 浏览量与评论
- icon: comment-dots
- details: 配合 Waline 来开启阅读量统计与评论支持
- link: https://theme-hope.vuejs.press/zh/guide/feature/comment.html
-
- - title: 文章信息
- icon: circle-info
- details: 为你的文章添加作者、写作日期、预计阅读时间、字数统计等信息
- link: https://theme-hope.vuejs.press/zh/guide/feature/page-info.html
-
- - title: 文章加密
- icon: lock
- details: 你可以为你的特定页面或特定目录进行加密,以便陌生人不能随意访问它们
- link: https://theme-hope.vuejs.press/zh/guide/feature/encrypt.html
-
- - title: 搜索支持
- icon: search
- details: 支持 docsearch 和基于客户端的搜索
- link: https://theme-hope.vuejs.press/zh/guide/feature/search.html
-
- - title: 代码复制
- icon: copy
- details: 一键复制代码块中的代码
- link: https://theme-hope.vuejs.press/zh/guide/feature/copy-code.html
-
- - title: 图片预览
- icon: image
- details: 像相册一样允许你浏览、缩放并分享你的页面图片
- link: https://theme-hope.vuejs.press/zh/guide/feature/photo-swipe.html
-
- - header: 博客
- description: 通过主题创建个人博客
- image: /assets/image/blog.svg
- bgImage: https://theme-hope-assets.vuejs.press/bg/5-light.svg
- bgImageDark: https://theme-hope-assets.vuejs.press/bg/5-dark.svg
- highlights:
- - title: 博客功能
- icon: blog
- details: 通过文章的日期、标签和分类展示文章
- link: https://theme-hope.vuejs.press/zh/guide/blog/intro.html
-
- - title: 博客主页
- icon: home
- details: 全新博客主页
- link: https://theme-hope.vuejs.press/zh/guide/blog/home.html
-
- - title: 博主信息
- icon: home
- details: 自定义名称、头像、座右铭和社交媒体链接
- link: https://theme-hope.vuejs.press/zh/guide/blog/blogger.html
-
- - title: 时间线
- icon: home
- details: 在时间线中浏览和通读博文
- link: https://theme-hope.vuejs.press/zh/guide/blog/timeline.html
-
- - header: 高级
- description: 增强站点与用户体验的高级功能
- image: /assets/image/advanced.svg
- bgImage: https://theme-hope-assets.vuejs.press/bg/4-light.svg
- bgImageDark: https://theme-hope-assets.vuejs.press/bg/4-dark.svg
- highlights:
- - title: SEO 增强
- icon: dumbbell
- details: 将最终生成的网页针对搜索引擎进行优化。
- link: https://theme-hope.vuejs.press/zh/guide/advanced/seo.html
-
- - title: Sitemap
- icon: sitemap
- details: 自动为你的网站生成 Sitemap
- link: https://theme-hope.vuejs.press/zh/guide/advanced/sitemap.html
-
- - title: Feed 支持
- icon: rss
- details: 生成你的 Feed,并通知你的用户订阅它
- link: https://theme-hope.vuejs.press/zh/guide/advanced/feed.html
-
- - title: PWA 支持
- icon: mobile-screen
- details: 让你的网站更像一个 APP
- link: https://theme-hope.vuejs.press/zh/guide/advanced/pwa.html
-
+ - title: 安装 Git 和 Python3.10+
+ - title: 使用 git clone https://github.com/snowykami/LiteyukiBot
以克隆项目至本地。
+ details: 如果无法连接到GitHub,可以使用 git clone https://gitee.com/snowykami/LiteyukiBot
。
+ - title: 使用 cd LiteyukiBot
切换到项目目录。
+ - title: 使用 pip install -r requirements.txt
安装项目依赖。
+ details: 如果你有多个 Python 环境,请使用 pythonx -m pip install -r requirements.txt
。
+ - title: 使用 python main.py
启动项目。
copyright: false
footer: 使用 VuePress Theme Hope 主题 | MIT 协议, 版权所有 © 2019-present Mr.Hope
----
-
-这是项目主页的案例。你可以在这里放置你的主体内容。
-
-想要使用此布局,你需要在页面 front matter 中设置 `home: true`。
-
-配置项的相关说明详见 [项目主页配置](https://theme-hope.vuejs.press/zh/guide/layout/home/)。
+---
\ No newline at end of file
diff --git a/docs/demo/README.md b/docs/demo/README.md
index 31ede9b..8d83ff5 100644
--- a/docs/demo/README.md
+++ b/docs/demo/README.md
@@ -6,4 +6,4 @@ category:
- 使用指南
---
-
+a
diff --git a/docs/demo/layout.md b/docs/demo/layout.md
index b89b60a..123dc67 100644
--- a/docs/demo/layout.md
+++ b/docs/demo/layout.md
@@ -1,9 +1,8 @@
---
title: 布局
icon: object-group
-order: 2
-category:
- - 指南
+order: 3
+category: 使用指南
tag:
- 布局
---
diff --git a/docs/demo/page.md b/docs/demo/page.md
index 23d1b81..3758c7e 100644
--- a/docs/demo/page.md
+++ b/docs/demo/page.md
@@ -6,7 +6,7 @@ cover: /assets/images/cover1.jpg
# 这是页面的图标
icon: file
# 这是侧边栏的顺序
-order: 3
+order: 4
# 设置作者
author: Ms.Hope
# 设置写作时间
diff --git a/docs/deployment/README.md b/docs/deployment/README.md
new file mode 100644
index 0000000..e4370a2
--- /dev/null
+++ b/docs/deployment/README.md
@@ -0,0 +1,6 @@
+---
+title: 快速部署
+index: false
+icon: laptop-code
+category: 安装和配置
+---
diff --git a/docs/deployment/config.md b/docs/deployment/config.md
new file mode 100644
index 0000000..9a4f991
--- /dev/null
+++ b/docs/deployment/config.md
@@ -0,0 +1,9 @@
+---
+title: 配置
+icon: object-group
+order: 2
+category: 使用指南
+tag:
+ - 配置
+ - 部署
+---
diff --git a/docs/deployment/install.md b/docs/deployment/install.md
new file mode 100644
index 0000000..ea1b9f8
--- /dev/null
+++ b/docs/deployment/install.md
@@ -0,0 +1,14 @@
+---
+title: 安装
+icon: object-group
+order: 1
+category: 使用指南
+tag:
+ - 安装
+---
+
+1. 安装 `Git` 和 `Python3.10+` 环境
+2. 克隆项目 `git clone https://github.com/snowykami/LiteyukiBot` (无法连接可以用`https://gitee.com/snowykami/LiteyukiBot`)
+3. 切换目录`cd LiteyukiBot`
+4. 安装依赖`pip install -r requirements.txt`(如果多个Python环境请指定后安装`pythonx -m pip install -r requirements.txt`)
+5. 启动`python main.py`
diff --git a/docs/usage/README.md b/docs/usage/README.md
new file mode 100644
index 0000000..cec4fce
--- /dev/null
+++ b/docs/usage/README.md
@@ -0,0 +1,6 @@
+---
+title: 使用指南
+index: false
+icon: laptop-code
+category: 使用指南
+---
diff --git a/docs/.vuepress/config.ts b/docs/.vuepress/config.ts
index 8a40186..2b8b1d1 100644
--- a/docs/.vuepress/config.ts
+++ b/docs/.vuepress/config.ts
@@ -1,15 +1,21 @@
-import { defineUserConfig } from "vuepress";
+import {defineUserConfig} from "vuepress";
import theme from "./theme.js";
+import viteBundler from "@vuepress/bundler-vite";
export default defineUserConfig({
- base: "/",
+ base: "/",
- lang: "zh-CN",
- title: "文档演示",
- description: "vuepress-theme-hope 的文档演示",
+ lang: "zh-CN",
+ title: "LiteyukiBot",
+ description: "An OneBot Standard ChatBot",
+ head: [
+// 设置 favor.ico,.vuepress/public 下
+ [
+ 'link', {rel: 'icon', href: 'https://cdn.liteyuki.icu/favicon.ico'}
+ ]
+ ],
- theme,
-
- // 和 PWA 一起启用
- // shouldPrefetch: false,
+ theme,
+ // 和 PWA 一起启用
+ // shouldPrefetch: false,
});